/**
  ******************************************************************************
  * @file    Project/STM32F10x_StdPeriph_Template/main.c 
  * @author  MCD Application Team
  * @version V3.5.0
  * @date    08-April-2011
  * @brief   Main program body
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2011 STMicroelectronics</center></h2>
  ******************************************************************************
  */  

/* Includes ------------------------------------------------------------------*/
#include "main.h"


/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define MESSAGE1   "  STM32F103VBT6   " 

/* Private macro -------------------------------------------------------------*/

/* Private variables ---------------------------------------------------------*/
u32 count = 0;

/* Private function prototypes -----------------------------------------------*/
static void Task1( void *pvParameters );
//static xTaskHandle task1;


/* Private functions ---------------------------------------------------------*/


int main(void)
{
  SYSTickInit();
  AppGPIOInit();
  AppUARTInit();

  printf("%s", MESSAGE1);

  
  /* Create Task */
  xTaskCreate( Task1, "Task1", /*TASK_SIZE*/ 240 , NULL, 1, /*&task1*/ NULL);       
  
  /* Start the scheduler. */
  vTaskStartScheduler();
  

  return 0;
}

/******************************************************************************************************/
/* Task1	:	       50msec task call               					      */												
/******************************************************************************************************/
void Task1( void *pvParameters ){
  portTickType gpio_Time; 
  
  gpio_Time = xTaskGetTickCount();    
  printf("%s ", MESSAGE1);
  while(1)
  {    
    GPIOB->ODR ^= GPIO_Pin_6;
    vTaskDelayUntil( &gpio_Time, 1000 );     
  }
  
}

/****************************************************************************************************************************/
/****************************************************************************************************************************/

void SYSTickInit(void)
{
  /* Setup SysTick Timer for 1 msec interrupts  */
  if (SysTick_Config(SystemCoreClock/1000))
  { 
    /* Capture error */ 
    while (1);
  }  
}

void AppUARTInit()
{
  GPIO_InitTypeDef GPIO_InitStructure;
  USART_InitTypeDef USART_InitStructure;
  // Initialize RCC
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA|RCC_APB2Periph_AFIO, ENABLE);
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_USART1, ENABLE);
  
  //Initialize TXD Pin
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_9;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
  
  //Initialize RXD Pin
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_10;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN_FLOATING;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
  
  
  /* USARTx configured as follow:
  - BaudRate = 115200 baud  
  - Word Length = 8 Bits
  - One Stop Bit
  - No parity
  - Hardware flow control disabled (RTS and CTS signals)
  - Receive and transmit enabled
  */
  USART_InitStructure.USART_BaudRate = 115200;
  USART_InitStructure.USART_WordLength = USART_WordLength_8b;
  USART_InitStructure.USART_StopBits = USART_StopBits_1;
  USART_InitStructure.USART_Parity = USART_Parity_No;
  USART_InitStructure.USART_HardwareFlowControl = USART_HardwareFlowControl_None;
  USART_InitStructure.USART_Mode = USART_Mode_Rx | USART_Mode_Tx;
  
  USART_Init(USART1, &USART_InitStructure);
  USART_Cmd(USART1, ENABLE);
}

void AppGPIOInit()
{
  GPIO_InitTypeDef GPIO_InitStructure;
  
  // GPIO Clock Enable
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB,ENABLE);    // GPIO B  - LED OUT PORT
  
  
  /* Configure the GPIO_LED pin(OUT) */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7 | GPIO_Pin_8 | GPIO_Pin_9;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOB, &GPIO_InitStructure);

  GPIO_SetBits(GPIOB, GPIO_Pin_5 | GPIO_Pin_7 | GPIO_Pin_9);
}

size_t __write(int handle, const unsigned char *buf, size_t bufSize)
{
  size_t nChars = 0;
  
  if(handle == -1) return 0;
  else if(handle != 1 && handle != 2 ) return -1;
  
  for(;bufSize > 0; --bufSize)
  {
    while(USART_GetFlagStatus(USART1, USART_FLAG_TXE) == RESET);
    USART_SendData(USART1, (uint8_t)*buf);
    ++buf;
    ++nChars;
  }
  
  return nChars;
}


/**
  * @brief  Inserts a delay time.
  * @param  nTime: specifies the delay time length, in milliseconds.
  * @retval None
  */
void Delay(uint32_t nTime)
{ 
  TimingDelay = nTime;

  while(TimingDelay != 0);
}

/**
  * @brief  Decrements the TimingDelay variable.
  * @param  None
  * @retval None
  */
void TimingDelay_Decrement(void)
{
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}